@@ -6,9 +6,9 @@ Type annotations for finspace-data service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_finspace_data.type_defs import ChangesetErrorInfoTypeDef
+    from mypy_boto3_finspace_data.type_defs import AssociateUserToPermissionGroupRequestRequestTypeDef
 
-    data: ChangesetErrorInfoTypeDef = {...}
+    data: AssociateUserToPermissionGroupRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -25,6 +25,7 @@ from .literals import (
     ErrorCategoryType,
     ExportFileFormatType,
     IngestionStatusType,
+    PermissionGroupMembershipStatusType,
     UserStatusType,
     UserTypeType,
     locationTypeType,
@@ -37,10 +38,12 @@ else:
 
 
 __all__ = (
+    "AssociateUserToPermissionGroupRequestRequestTypeDef",
+    "ResponseMetadataTypeDef",
+    "AwsCredentialsTypeDef",
     "ChangesetErrorInfoTypeDef",
     "ColumnDefinitionTypeDef",
     "CreateChangesetRequestRequestTypeDef",
-    "ResponseMetadataTypeDef",
     "DataViewDestinationTypeParamsTypeDef",
     "DatasetOwnerInfoTypeDef",
     "CreatePermissionGroupRequestRequestTypeDef",
@@ -50,10 +53,15 @@ __all__ = (
     "DeleteDatasetRequestRequestTypeDef",
     "DeletePermissionGroupRequestRequestTypeDef",
     "DisableUserRequestRequestTypeDef",
+    "DisassociateUserFromPermissionGroupRequestRequestTypeDef",
     "EnableUserRequestRequestTypeDef",
     "GetChangesetRequestRequestTypeDef",
     "GetDataViewRequestRequestTypeDef",
     "GetDatasetRequestRequestTypeDef",
+    "GetExternalDataViewAccessDetailsRequestRequestTypeDef",
+    "S3LocationTypeDef",
+    "GetPermissionGroupRequestRequestTypeDef",
+    "PermissionGroupTypeDef",
     "GetProgrammaticAccessCredentialsRequestRequestTypeDef",
     "GetUserRequestRequestTypeDef",
     "GetWorkingLocationRequestRequestTypeDef",
@@ -61,8 +69,11 @@ __all__ = (
     "ListChangesetsRequestRequestTypeDef",
     "ListDataViewsRequestRequestTypeDef",
     "ListDatasetsRequestRequestTypeDef",
+    "ListPermissionGroupsByUserRequestRequestTypeDef",
+    "PermissionGroupByUserTypeDef",
     "ListPermissionGroupsRequestRequestTypeDef",
-    "PermissionGroupTypeDef",
+    "ListUsersByPermissionGroupRequestRequestTypeDef",
+    "UserByPermissionGroupTypeDef",
     "ListUsersRequestRequestTypeDef",
     "UserTypeDef",
     "ResourcePermissionTypeDef",
@@ -70,8 +81,7 @@ __all__ = (
     "UpdateChangesetRequestRequestTypeDef",
     "UpdatePermissionGroupRequestRequestTypeDef",
     "UpdateUserRequestRequestTypeDef",
-    "ChangesetSummaryTypeDef",
-    "SchemaDefinitionTypeDef",
+    "AssociateUserToPermissionGroupResponseTypeDef",
     "CreateChangesetResponseTypeDef",
     "CreateDataViewResponseTypeDef",
     "CreateDatasetResponseTypeDef",
@@ -80,8 +90,8 @@ __all__ = (
     "DeleteDatasetResponseTypeDef",
     "DeletePermissionGroupResponseTypeDef",
     "DisableUserResponseTypeDef",
+    "DisassociateUserFromPermissionGroupResponseTypeDef",
     "EnableUserResponseTypeDef",
-    "GetChangesetResponseTypeDef",
     "GetUserResponseTypeDef",
     "GetWorkingLocationResponseTypeDef",
     "ResetUserPasswordResponseTypeDef",
@@ -89,16 +99,23 @@ __all__ = (
     "UpdateDatasetResponseTypeDef",
     "UpdatePermissionGroupResponseTypeDef",
     "UpdateUserResponseTypeDef",
+    "ChangesetSummaryTypeDef",
+    "GetChangesetResponseTypeDef",
+    "SchemaDefinitionTypeDef",
     "CreateDataViewRequestRequestTypeDef",
     "GetProgrammaticAccessCredentialsResponseTypeDef",
     "DataViewSummaryTypeDef",
     "GetDataViewResponseTypeDef",
+    "GetExternalDataViewAccessDetailsResponseTypeDef",
+    "GetPermissionGroupResponseTypeDef",
+    "ListPermissionGroupsResponseTypeDef",
     "ListChangesetsRequestListChangesetsPaginateTypeDef",
     "ListDataViewsRequestListDataViewsPaginateTypeDef",
     "ListDatasetsRequestListDatasetsPaginateTypeDef",
     "ListPermissionGroupsRequestListPermissionGroupsPaginateTypeDef",
     "ListUsersRequestListUsersPaginateTypeDef",
-    "ListPermissionGroupsResponseTypeDef",
+    "ListPermissionGroupsByUserResponseTypeDef",
+    "ListUsersByPermissionGroupResponseTypeDef",
     "ListUsersResponseTypeDef",
     "PermissionGroupParamsTypeDef",
     "ListChangesetsResponseTypeDef",
@@ -111,6 +128,51 @@ __all__ = (
     "ListDatasetsResponseTypeDef",
 )
 
+_RequiredAssociateUserToPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredAssociateUserToPermissionGroupRequestRequestTypeDef",
+    {
+        "permissionGroupId": str,
+        "userId": str,
+    },
+)
+_OptionalAssociateUserToPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalAssociateUserToPermissionGroupRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class AssociateUserToPermissionGroupRequestRequestTypeDef(
+    _RequiredAssociateUserToPermissionGroupRequestRequestTypeDef,
+    _OptionalAssociateUserToPermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
+AwsCredentialsTypeDef = TypedDict(
+    "AwsCredentialsTypeDef",
+    {
+        "accessKeyId": str,
+        "secretAccessKey": str,
+        "sessionToken": str,
+        "expiration": int,
+    },
+    total=False,
+)
+
 ChangesetErrorInfoTypeDef = TypedDict(
     "ChangesetErrorInfoTypeDef",
     {
@@ -154,17 +216,6 @@ class CreateChangesetRequestRequestTypeDef(
     pass
 
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
 _RequiredDataViewDestinationTypeParamsTypeDef = TypedDict(
     "_RequiredDataViewDestinationTypeParamsTypeDef",
     {
@@ -330,6 +381,29 @@ class DisableUserRequestRequestTypeDef(
     pass
 
 
+_RequiredDisassociateUserFromPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredDisassociateUserFromPermissionGroupRequestRequestTypeDef",
+    {
+        "permissionGroupId": str,
+        "userId": str,
+    },
+)
+_OptionalDisassociateUserFromPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalDisassociateUserFromPermissionGroupRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DisassociateUserFromPermissionGroupRequestRequestTypeDef(
+    _RequiredDisassociateUserFromPermissionGroupRequestRequestTypeDef,
+    _OptionalDisassociateUserFromPermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredEnableUserRequestRequestTypeDef = TypedDict(
     "_RequiredEnableUserRequestRequestTypeDef",
     {
@@ -374,6 +448,43 @@ GetDatasetRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetExternalDataViewAccessDetailsRequestRequestTypeDef = TypedDict(
+    "GetExternalDataViewAccessDetailsRequestRequestTypeDef",
+    {
+        "dataViewId": str,
+        "datasetId": str,
+    },
+)
+
+S3LocationTypeDef = TypedDict(
+    "S3LocationTypeDef",
+    {
+        "bucket": str,
+        "key": str,
+    },
+)
+
+GetPermissionGroupRequestRequestTypeDef = TypedDict(
+    "GetPermissionGroupRequestRequestTypeDef",
+    {
+        "permissionGroupId": str,
+    },
+)
+
+PermissionGroupTypeDef = TypedDict(
+    "PermissionGroupTypeDef",
+    {
+        "permissionGroupId": str,
+        "name": str,
+        "description": str,
+        "applicationPermissions": List[ApplicationPermissionType],
+        "createTime": int,
+        "lastModifiedTime": int,
+        "membershipStatus": PermissionGroupMembershipStatusType,
+    },
+    total=False,
+)
+
 _RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef = TypedDict(
     "_RequiredGetProgrammaticAccessCredentialsRequestRequestTypeDef",
     {
@@ -474,6 +585,39 @@ ListDatasetsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListPermissionGroupsByUserRequestRequestTypeDef = TypedDict(
+    "_RequiredListPermissionGroupsByUserRequestRequestTypeDef",
+    {
+        "userId": str,
+        "maxResults": int,
+    },
+)
+_OptionalListPermissionGroupsByUserRequestRequestTypeDef = TypedDict(
+    "_OptionalListPermissionGroupsByUserRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListPermissionGroupsByUserRequestRequestTypeDef(
+    _RequiredListPermissionGroupsByUserRequestRequestTypeDef,
+    _OptionalListPermissionGroupsByUserRequestRequestTypeDef,
+):
+    pass
+
+
+PermissionGroupByUserTypeDef = TypedDict(
+    "PermissionGroupByUserTypeDef",
+    {
+        "permissionGroupId": str,
+        "name": str,
+        "membershipStatus": PermissionGroupMembershipStatusType,
+    },
+    total=False,
+)
+
 _RequiredListPermissionGroupsRequestRequestTypeDef = TypedDict(
     "_RequiredListPermissionGroupsRequestRequestTypeDef",
     {
@@ -496,15 +640,41 @@ class ListPermissionGroupsRequestRequestTypeDef(
     pass
 
 
-PermissionGroupTypeDef = TypedDict(
-    "PermissionGroupTypeDef",
+_RequiredListUsersByPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredListUsersByPermissionGroupRequestRequestTypeDef",
     {
         "permissionGroupId": str,
-        "name": str,
-        "description": str,
-        "applicationPermissions": List[ApplicationPermissionType],
-        "createTime": int,
-        "lastModifiedTime": int,
+        "maxResults": int,
+    },
+)
+_OptionalListUsersByPermissionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalListUsersByPermissionGroupRequestRequestTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListUsersByPermissionGroupRequestRequestTypeDef(
+    _RequiredListUsersByPermissionGroupRequestRequestTypeDef,
+    _OptionalListUsersByPermissionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+UserByPermissionGroupTypeDef = TypedDict(
+    "UserByPermissionGroupTypeDef",
+    {
+        "userId": str,
+        "status": UserStatusType,
+        "firstName": str,
+        "lastName": str,
+        "emailAddress": str,
+        "type": UserTypeType,
+        "apiAccess": ApiAccessType,
+        "apiAccessPrincipalArn": str,
+        "membershipStatus": PermissionGroupMembershipStatusType,
     },
     total=False,
 )
@@ -654,33 +824,12 @@ class UpdateUserRequestRequestTypeDef(
     pass
 
 
-ChangesetSummaryTypeDef = TypedDict(
-    "ChangesetSummaryTypeDef",
+AssociateUserToPermissionGroupResponseTypeDef = TypedDict(
+    "AssociateUserToPermissionGroupResponseTypeDef",
     {
-        "changesetId": str,
-        "changesetArn": str,
-        "datasetId": str,
-        "changeType": ChangeTypeType,
-        "sourceParams": Dict[str, str],
-        "formatParams": Dict[str, str],
-        "createTime": int,
-        "status": IngestionStatusType,
-        "errorInfo": ChangesetErrorInfoTypeDef,
-        "activeUntilTimestamp": int,
-        "activeFromTimestamp": int,
-        "updatesChangesetId": str,
-        "updatedByChangesetId": str,
+        "statusCode": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
-    total=False,
-)
-
-SchemaDefinitionTypeDef = TypedDict(
-    "SchemaDefinitionTypeDef",
-    {
-        "columns": Sequence[ColumnDefinitionTypeDef],
-        "primaryKeyColumns": Sequence[str],
-    },
-    total=False,
 )
 
 CreateChangesetResponseTypeDef = TypedDict(
@@ -749,30 +898,18 @@ DisableUserResponseTypeDef = TypedDict(
     },
 )
 
-EnableUserResponseTypeDef = TypedDict(
-    "EnableUserResponseTypeDef",
+DisassociateUserFromPermissionGroupResponseTypeDef = TypedDict(
+    "DisassociateUserFromPermissionGroupResponseTypeDef",
     {
-        "userId": str,
+        "statusCode": int,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-GetChangesetResponseTypeDef = TypedDict(
-    "GetChangesetResponseTypeDef",
+EnableUserResponseTypeDef = TypedDict(
+    "EnableUserResponseTypeDef",
     {
-        "changesetId": str,
-        "changesetArn": str,
-        "datasetId": str,
-        "changeType": ChangeTypeType,
-        "sourceParams": Dict[str, str],
-        "formatParams": Dict[str, str],
-        "createTime": int,
-        "status": IngestionStatusType,
-        "errorInfo": ChangesetErrorInfoTypeDef,
-        "activeUntilTimestamp": int,
-        "activeFromTimestamp": int,
-        "updatesChangesetId": str,
-        "updatedByChangesetId": str,
+        "userId": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -849,6 +986,55 @@ UpdateUserResponseTypeDef = TypedDict(
     },
 )
 
+ChangesetSummaryTypeDef = TypedDict(
+    "ChangesetSummaryTypeDef",
+    {
+        "changesetId": str,
+        "changesetArn": str,
+        "datasetId": str,
+        "changeType": ChangeTypeType,
+        "sourceParams": Dict[str, str],
+        "formatParams": Dict[str, str],
+        "createTime": int,
+        "status": IngestionStatusType,
+        "errorInfo": ChangesetErrorInfoTypeDef,
+        "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
+        "updatesChangesetId": str,
+        "updatedByChangesetId": str,
+    },
+    total=False,
+)
+
+GetChangesetResponseTypeDef = TypedDict(
+    "GetChangesetResponseTypeDef",
+    {
+        "changesetId": str,
+        "changesetArn": str,
+        "datasetId": str,
+        "changeType": ChangeTypeType,
+        "sourceParams": Dict[str, str],
+        "formatParams": Dict[str, str],
+        "createTime": int,
+        "status": IngestionStatusType,
+        "errorInfo": ChangesetErrorInfoTypeDef,
+        "activeUntilTimestamp": int,
+        "activeFromTimestamp": int,
+        "updatesChangesetId": str,
+        "updatedByChangesetId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SchemaDefinitionTypeDef = TypedDict(
+    "SchemaDefinitionTypeDef",
+    {
+        "columns": Sequence[ColumnDefinitionTypeDef],
+        "primaryKeyColumns": Sequence[str],
+    },
+    total=False,
+)
+
 _RequiredCreateDataViewRequestRequestTypeDef = TypedDict(
     "_RequiredCreateDataViewRequestRequestTypeDef",
     {
@@ -922,6 +1108,32 @@ GetDataViewResponseTypeDef = TypedDict(
     },
 )
 
+GetExternalDataViewAccessDetailsResponseTypeDef = TypedDict(
+    "GetExternalDataViewAccessDetailsResponseTypeDef",
+    {
+        "credentials": AwsCredentialsTypeDef,
+        "s3Location": S3LocationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetPermissionGroupResponseTypeDef = TypedDict(
+    "GetPermissionGroupResponseTypeDef",
+    {
+        "permissionGroup": PermissionGroupTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListPermissionGroupsResponseTypeDef = TypedDict(
+    "ListPermissionGroupsResponseTypeDef",
+    {
+        "permissionGroups": List[PermissionGroupTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredListChangesetsRequestListChangesetsPaginateTypeDef = TypedDict(
     "_RequiredListChangesetsRequestListChangesetsPaginateTypeDef",
     {
@@ -990,10 +1202,19 @@ ListUsersRequestListUsersPaginateTypeDef = TypedDict(
     total=False,
 )
 
-ListPermissionGroupsResponseTypeDef = TypedDict(
-    "ListPermissionGroupsResponseTypeDef",
+ListPermissionGroupsByUserResponseTypeDef = TypedDict(
+    "ListPermissionGroupsByUserResponseTypeDef",
     {
-        "permissionGroups": List[PermissionGroupTypeDef],
+        "permissionGroups": List[PermissionGroupByUserTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListUsersByPermissionGroupResponseTypeDef = TypedDict(
+    "ListUsersByPermissionGroupResponseTypeDef",
+    {
+        "users": List[UserByPermissionGroupTypeDef],
         "nextToken": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
